@@ -104,7 +104,7 @@ if __name__ == "__main__":
                 processedFiles[moduleName]['version'] = checkPackageVersion(moduleName)
 
             processedFiles[moduleName]['files'].add(currentFile)
-            processedFiles[moduleName]['explicit'] |= (callingFile.endswith("CMakeLists.txt"))
+            processedFiles[moduleName]['explicit'] |= (callingFile.endswith("CMakeLists.txt") or callingFile.endswith("Qt5/Qt5Config.cmake") or callingFile.endswith("FindKF5.cmake"))
 
     print("[")
     first = True
@@ -115,10 +115,18 @@ if __name__ == "__main__":
 
         value['files'] = list(value['files'])
         value['project'] = v
-        print("\t%s" % (json.dumps(value)), end='')
         if v in lookedUpPackages:
+            if value['version'] is None:
+                line = lookedUpPackages[v]
+                isVersion = line[:line.find(' ')]
+
+                if len(isVersion)>0 and isVersion[0].isdigit():
+                    value['version'] = { 'used': None, 'requested': isVersion }
+
             del lookedUpPackages[v]
 
+        print("\t%s" % (json.dumps(value)), end='')
+
     # display missing packages
     for v in lookedUpPackages:
         if not first:
